#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pyhipku import encode
from pyhipku import decode

def test_ipv4():
    assert decode(encode('0.0.0.0')) == '0.0.0.0'
    assert decode(encode('82.158.98.2')) == '82.158.98.2'
    assert decode(encode('255.255.255.255')) == '255.255.255.255'


def test_ipv6():
    assert decode(encode('0:0:0:0:0:0:0:0')) == '0:0:0:0:0:0:0:0'
    assert (decode(encode('2c8f:27aa:61fd:56ec:7ebe:d03a:1f50:475f')) ==
            '2c8f:27aa:61fd:56ec:7ebe:d03a:1f50:475f')
    assert (decode(encode('ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff')) ==
            'ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff')


def test_abbreviated_ipv6():
    assert decode(encode('::0')) == '0:0:0:0:0:0:0:0'
    assert decode(encode('0::')) == '0:0:0:0:0:0:0:0'
    assert decode(encode('0::0')) == '0:0:0:0:0:0:0:0'
    assert decode(encode('0:0::0:0')) == '0:0:0:0:0:0:0:0'



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from string import capitalize

from dictionary import *


def encode(ip):
    """Encode IP address as hiaku"""
    is_ipv6 = ip_is_ipv6(ip)
    decimal_octect_array = split_ip(ip, is_ipv6)
    factord_octet_array = factor_octets(decimal_octect_array, is_ipv6)
    encoded_word_array = encode_words(factord_octet_array, is_ipv6)
    haiku_text = write_haiku(encoded_word_array, is_ipv6)
    return haiku_text


def ip_is_ipv6(ip):
    """IP address is IPv6 or not, return True if it is"""
    if ip.find(':') != -1:
        return True
    elif ip.find('.') != -1:
        return False
    else:
        raise ValueError("Formatting error in IP address input. "
                         "Contains neither ':' or '.'")


def split_ip(ip, is_ipv6):
    """Split IP address and convert to integer"""
    if is_ipv6:
        separator = ':'
        octet_num = 8
    else:
        separator = '.'
        octet_num = 4
    # Remove new_line and space characters.
    ip = ''.join(ip.split())
    octet_array = ip.split(separator)
    # Replace missing octect with 0 if IPv6 address is in abbreviated fomat.
    if len(octet_array) < octet_num:
        if is_ipv6:
            octet_missing_num = octet_num - len(octet_array)
            octet_array = pad_octets(octet_array, octet_missing_num)
        else:
            raise ValueError("Formatting error in IP address input. "
                             "IPv4 address has fewer than 4 octets.")
    decimal_octect_array = []
    if is_ipv6:
        for i in range(len(octet_array)):
            decimal_octect_array.append(int(octet_array[i], 16))
    else:
        decimal_octect_array = [int(num) for num in octet_array]
    return decimal_octect_array


def pad_octets(octet_array, octet_missing_num):
    """Pad appropriate number of 0 octects if IPv6 is abbreviated"""
    padded_octect = '0'
    length = len(octet_array)
    # If the first or last octect is blank, zero them.
    if octet_array[0] == '':
        octet_array[0] = padded_octect
    if octet_array[length - 1] == '':
        octet_array[length - 1] = padded_octect
    # Check the rest of the array for blank octects and pad as needed.
    for i in range(length):
        if octet_array[i] == '':
            octet_array[i] = padded_octect
            for j in range(octet_missing_num):
                octet_array.insert(i, padded_octect)
    return octet_array


def factor_octets(octet_array, is_ipv6):
    """Convert each decimal octet into a factor of the
    divisor (16 or 256) and a remainder"""
    if is_ipv6:
        divisor = 256
    else:
        divisor = 16
    factord_octet_array = []
    for i in range(len(octet_array)):
        factord_octet_array.extend([octet_array[i] / divisor,
                                    octet_array[i] % divisor])
    return factord_octet_array


def encode_words(factor_array, is_ipv6):
    """Get a word array from the dictionary according to the factor_array"""
    key = get_key(is_ipv6)
    encoded_word_array = []
    for i in range(len(factor_array)):
        encoded_word_array.append(key[i][factor_array[i]])
    return encoded_word_array


def get_key(is_ipv6):
    """Return an array of dictionaries representing the correct word
    order for the haiku"""
    if is_ipv6:
        key = [adjectives, nouns, adjectives, nouns, verbs, adjectives,
               adjectives, adjectives, adjectives, adjectives, nouns,
               adjectives, nouns, verbs, adjectives, nouns]
    else:
        key = [animal_adjectives, animal_colors, animal_nouns, animal_verbs,
               nature_adjectives, nature_nouns, plant_nouns, plant_verbs]
    return key


def write_haiku(word_array, is_ipv6):
    """Return the beautiful haiku"""
    # String to place in schema to show word slot.
    octct = 'OCTET'
    schema = get_schema(is_ipv6, octct)

    # Replace each instance of 'octet' in the schema with a word from
    # the encoded word array.
    for i in range(len(word_array)):
        for j in range(len(schema)):
            if schema[j] == octct:
                schema[j] = word_array[i]
                break
    # Capitalize appropriate words.
    schema = capitalize_haiku(schema)
    haiku = ''.join(schema)
    return haiku


def get_schema(is_ipv6, octet):
    """Get the template with word slots"""
    new_line = '\n'
    period = '.'
    space = ' '
    non_words = [new_line, period, space]
    if is_ipv6:
        schema = [octet, octet, 'and', octet, octet, new_line, octet, octet,
                  octet, octet, octet, octet, octet, period, new_line, octet,
                  octet, octet, octet, octet, period, new_line]
    else:
        schema = ['The', octet, octet, octet, new_line, octet, 'in the',
                  octet, octet, period, new_line, octet, octet, period,
                  new_line]
    space_num = 0
    # Add spaces before words except the first word.
    for i in range(1, len(schema)):
        i = i + space_num
        insert_space = True
        # If the current entry is a non_word, don't add a space.
        if schema[i] in non_words:
            insert_space = False
        # If the previous entry is a new_line, don't add a space.
        if schema[i-1] == new_line:
            insert_space = False
        if insert_space:
            schema.insert(i, space)
            space_num = space_num + 1
    return schema


def capitalize_haiku(haiku_array):
    """Capitalize appropriate words in haiku"""
    period = '.'
    # Always capitalize the first word.
    haiku_array[0] = capitalize(haiku_array[0])
    for i in range(1, len(haiku_array)):
        if haiku_array[i] == period and i+2 < len(haiku_array):
            # If the current entry is a period then the next entry will
            # be a new_line or a space, so check two positions after and
            # capitalize that entry, so long as it's a word.
            haiku_array[i+2] = capitalize(haiku_array[i+2])
    return haiku_array



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
    hipku
    ~~~~~

    Encode any IP address as a haiku.

    :copyright: (c) 2015 by lord63.
    :license: MIT, see LICENSE for more details.
"""

__title__ = "hipku"
__version__ = "0.1.0"
__author__ = "lord63"
__license__ = "MIT"
__copyright__ = "Copyright 2015 lord63"


from encode import *
from decode import *





#!/usr/bin/env python
# -*- coding: utf-8 -*-

# IPv4 dictionaries.

animal_adjectives = [
    'agile',
    'bashful',
    'clever',
    'clumsy',
    'drowsy',
    'fearful',
    'graceful',
    'hungry',
    'lonely',
    'morose',
    'placid',
    'ruthless',
    'silent',
    'thoughtful',
    'vapid',
    'weary']

animal_colors = [
    'beige',
    'black',
    'blue',
    'bright',
    'bronze',
    'brown',
    'dark',
    'drab',
    'green',
    'gold',
    'grey',
    'jade',
    'pale',
    'pink',
    'red',
    'white']

animal_nouns = [
    'ape',
    'bear',
    'crow',
    'dove',
    'frog',
    'goat',
    'hawk',
    'lamb',
    'mouse',
    'newt',
    'owl',
    'pig',
    'rat',
    'snake',
    'toad',
    'wolf']

animal_verbs = [
    'aches',
    'basks',
    'cries',
    'dives',
    'eats',
    'fights',
    'groans',
    'hunts',
    'jumps',
    'lies',
    'prowls',
    'runs',
    'sleeps',
    'thrives',
    'wakes',
    'yawns']

nature_adjectives = [
    'ancient',
    'barren',
    'blazing',
    'crowded',
    'distant',
    'empty',
    'foggy',
    'fragrant',
    'frozen',
    'moonlit',
    'peaceful',
    'quiet',
    'rugged',
    'serene',
    'sunlit',
    'wind-swept']

nature_nouns = [
    'canyon',
    'clearing',
    'desert',
    'foothills',
    'forest',
    'grasslands',
    'jungle',
    'meadow',
    'mountains',
    'prairie',
    'river',
    'rockpool',
    'sand-dune',
    'tundra',
    'valley',
    'wetlands']

plant_nouns = [
    'autumn colors',
    'cherry blossoms',
    'chrysanthemums',
    'crabapple blooms',
    'dry palm fronds',
    'fat horse chestnuts',
    'forget-me-nots',
    'jasmine petals',
    'lotus flowers',
    'ripe blackberries',
    'the maple seeds',
    'the pine needles',
    'tiger lillies',
    'water lillies',
    'willow branches',
    'yellowwood leaves']

plant_verbs = [
    'blow',
    'crunch',
    'dance',
    'drift',
    'drop',
    'fall',
    'grow',
    'pile',
    'rest',
    'roll',
    'show',
    'spin',
    'stir',
    'sway',
    'turn',
    'twist']

# IPv6 dictionaries.

adjectives = [
    'ace',
    'apt',
    'arched',
    'ash',
    'bad',
    'bare',
    'beige',
    'big',
    'black',
    'bland',
    'bleak',
    'blond',
    'blue',
    'blunt',
    'blush',
    'bold',
    'bone',
    'both',
    'bound',
    'brash',
    'brass',
    'brave',
    'brief',
    'brisk',
    'broad',
    'bronze',
    'brushed',
    'burned',
    'calm',
    'ceil',
    'chaste',
    'cheap',
    'chilled',
    'clean',
    'coarse',
    'cold',
    'cool',
    'corn',
    'crass',
    'crazed',
    'cream',
    'crisp',
    'crude',
    'cruel',
    'cursed',
    'cute',
    'daft',
    'damp',
    'dark',
    'dead',
    'deaf',
    'dear',
    'deep',
    'dense',
    'dim',
    'drab',
    'dry',
    'dull',
    'faint',
    'fair',
    'fake',
    'false',
    'famed',
    'far',
    'fast',
    'fat',
    'fierce',
    'fine',
    'firm',
    'flat',
    'flawed',
    'fond',
    'foul',
    'frail',
    'free',
    'fresh',
    'full',
    'fun',
    'glum',
    'good',
    'grave',
    'gray',
    'great',
    'green',
    'grey',
    'grim',
    'gruff',
    'hard',
    'harsh',
    'high',
    'hoarse',
    'hot',
    'huge',
    'hurt',
    'ill',
    'jade',
    'jet',
    'jinxed',
    'keen',
    'kind',
    'lame',
    'lank',
    'large',
    'last',
    'late',
    'lean',
    'lewd',
    'light',
    'limp',
    'live',
    'loath',
    'lone',
    'long',
    'loose',
    'lost',
    'louche',
    'loud',
    'low',
    'lush',
    'mad',
    'male',
    'masked',
    'mean',
    'meek',
    'mild',
    'mint',
    'moist',
    'mute',
    'near',
    'neat',
    'new',
    'nice',
    'nude',
    'numb',
    'odd',
    'old',
    'pained',
    'pale',
    'peach',
    'pear',
    'peeved',
    'pink',
    'piqued',
    'plain',
    'plum',
    'plump',
    'plush',
    'poor',
    'posed',
    'posh',
    'prim',
    'prime',
    'prompt',
    'prone',
    'proud',
    'prune',
    'puce',
    'pure',
    'quaint',
    'quartz',
    'quick',
    'rare',
    'raw',
    'real',
    'red',
    'rich',
    'ripe',
    'rough',
    'rude',
    'rushed',
    'rust',
    'sad',
    'safe',
    'sage',
    'sane',
    'scortched',
    'shaped',
    'sharp',
    'sheared',
    'short',
    'shrewd',
    'shrill',
    'shrunk',
    'shy',
    'sick',
    'skilled',
    'slain',
    'slick',
    'slight',
    'slim',
    'slow',
    'small',
    'smart',
    'smooth',
    'smug',
    'snide',
    'snug',
    'soft',
    'sore',
    'sought',
    'sour',
    'spare',
    'sparse',
    'spent',
    'spoilt',
    'spry',
    'squat',
    'staid',
    'stale',
    'stary',
    'staunch',
    'steep',
    'stiff',
    'strange',
    'straw',
    'stretched',
    'strict',
    'striped',
    'strong',
    'suave',
    'sure',
    'svelte',
    'swank',
    'sweet',
    'swift',
    'tall',
    'tame',
    'tan',
    'tart',
    'taut',
    'teal',
    'terse',
    'thick',
    'thin',
    'tight',
    'tiny',
    'tired',
    'toothed',
    'torn',
    'tough',
    'trim',
    'trussed',
    'twin',
    'used',
    'vague',
    'vain',
    'vast',
    'veiled',
    'vexed',
    'vile',
    'warm',
    'weak',
    'webbed',
    'wrong',
    'wry',
    'young']

nouns = [
    'ants',
    'apes',
    'asps',
    'balls',
    'barb',
    'barbs',
    'bass',
    'bats',
    'beads',
    'beaks',
    'bears',
    'bees',
    'bells',
    'belts',
    'birds',
    'blades',
    'blobs',
    'blooms',
    'boars',
    'boats',
    'bolts',
    'books',
    'bowls',
    'boys',
    'bream',
    'brides',
    'broods',
    'brooms',
    'brutes',
    'bucks',
    'bulbs',
    'bulls',
    'busks',
    'cakes',
    'calfs',
    'calves',
    'cats',
    'char',
    'chests',
    'choirs',
    'clams',
    'clans',
    'clouds',
    'clowns',
    'cod',
    'coins',
    'colts',
    'cones',
    'cords',
    'cows',
    'crabs',
    'cranes',
    'crows',
    'cults',
    'czars',
    'darts',
    'dates',
    'deer',
    'dholes',
    'dice',
    'discs',
    'does',
    'dogs',
    'doors',
    'dopes',
    'doves',
    'dreams',
    'drones',
    'ducks',
    'dunes',
    'dwarves',
    'eels',
    'eggs',
    'elk',
    'elks',
    'elms',
    'elves',
    'ewes',
    'eyes',
    'faces',
    'facts',
    'fawns',
    'feet',
    'ferns',
    'fish',
    'fists',
    'flames',
    'fleas',
    'flocks',
    'flutes',
    'foals',
    'foes',
    'fools',
    'fowl',
    'frogs',
    'fruits',
    'gangs',
    'gar',
    'geese',
    'gems',
    'germs',
    'ghosts',
    'gnomes',
    'goats',
    'grapes',
    'grooms',
    'grouse',
    'grubs',
    'guards',
    'gulls',
    'hands',
    'hares',
    'hawks',
    'heads',
    'hearts',
    'hens',
    'herbs',
    'hills',
    'hogs',
    'holes',
    'hordes',
    'ide',
    'jars',
    'jays',
    'kids',
    'kings',
    'kites',
    'lads',
    'lakes',
    'lambs',
    'larks',
    'lice',
    'lights',
    'limbs',
    'looms',
    'loons',
    'mares',
    'masks',
    'mice',
    'mimes',
    'minks',
    'mists',
    'mites',
    'mobs',
    'molds',
    'moles',
    'moons',
    'moths',
    'newts',
    'nymphs',
    'orbs',
    'orcs',
    'owls',
    'pearls',
    'pears',
    'peas',
    'perch',
    'pigs',
    'pikes',
    'pines',
    'plains',
    'plants',
    'plums',
    'pools',
    'prawns',
    'prunes',
    'pugs',
    'punks',
    'quail',
    'quails',
    'queens',
    'quills',
    'rafts',
    'rains',
    'rams',
    'rats',
    'rays',
    'ribs',
    'rocks',
    'rooks',
    'ruffs',
    'runes',
    'sands',
    'seals',
    'seas',
    'seeds',
    'serfs',
    'shards',
    'sharks',
    'sheep',
    'shells',
    'ships',
    'shoals',
    'shrews',
    'shrimp',
    'skate',
    'skies',
    'skunks',
    'sloths',
    'slugs',
    'smew',
    'smiles',
    'snails',
    'snakes',
    'snipes',
    'sole',
    'songs',
    'spades',
    'sprats',
    'sprouts',
    'squabs',
    'squads',
    'squares',
    'squid',
    'stars',
    'stoats',
    'stones',
    'storks',
    'strays',
    'suns',
    'swans',
    'swarms',
    'swells',
    'swifts',
    'tars',
    'teams',
    'teeth',
    'terns',
    'thorns',
    'threads',
    'thrones',
    'ticks',
    'toads',
    'tools',
    'trees',
    'tribes',
    'trolls',
    'trout',
    'tunes',
    'tusks',
    'veins',
    'verbs',
    'vines',
    'voles',
    'wasps',
    'waves',
    'wells',
    'whales',
    'whelks',
    'whiffs',
    'winds',
    'wolves',
    'worms',
    'wraiths',
    'wrens',
    'yaks']

verbs = [
    'aid',
    'arm',
    'awe',
    'axe',
    'bag',
    'bait',
    'bare',
    'bash',
    'bathe',
    'beat',
    'bid',
    'bilk',
    'blame',
    'bleach',
    'bleed',
    'bless',
    'bluff',
    'blur',
    'boast',
    'boost',
    'boot',
    'bore',
    'botch',
    'breed',
    'brew',
    'bribe',
    'brief',
    'brine',
    'broil',
    'browse',
    'bruise',
    'build',
    'burn',
    'burst',
    'call',
    'calm',
    'carve',
    'chafe',
    'chant',
    'charge',
    'chart',
    'cheat',
    'check',
    'cheer',
    'chill',
    'choke',
    'chomp',
    'choose',
    'churn',
    'cite',
    'clamp',
    'clap',
    'clasp',
    'claw',
    'clean',
    'cleanse',
    'clip',
    'cloack',
    'clone',
    'clutch',
    'coax',
    'crack',
    'crave',
    'crunch',
    'cry',
    'cull',
    'cure',
    'curse',
    'cuss',
    'dare',
    'daze',
    'dent',
    'dig',
    'ding',
    'doubt',
    'dowse',
    'drag',
    'drain',
    'drape',
    'draw',
    'dread',
    'dredge',
    'drill',
    'drink',
    'drip',
    'drive',
    'drop',
    'drown',
    'dry',
    'dump',
    'eat',
    'etch',
    'face',
    'fail',
    'fault',
    'fear',
    'feed',
    'feel',
    'fetch',
    'fight',
    'find',
    'fix',
    'flap',
    'flay',
    'flee',
    'fling',
    'flip',
    'float',
    'foil',
    'forge',
    'free',
    'freeze',
    'frisk',
    'gain',
    'glimpse',
    'gnaw',
    'goad',
    'gouge',
    'grab',
    'grasp',
    'graze',
    'grieve',
    'grip',
    'groom',
    'guard',
    'guards',
    'guide',
    'gulp',
    'gush',
    'halt',
    'harm',
    'hate',
    'haul',
    'haunt',
    'have',
    'heal',
    'hear',
    'help',
    'herd',
    'hex',
    'hire',
    'hit',
    'hoist',
    'hound',
    'hug',
    'hurl',
    'irk',
    'jab',
    'jeer',
    'join',
    'jolt',
    'keep',
    'kick',
    'kill',
    'kiss',
    'lash',
    'leash',
    'leave',
    'lift',
    'like',
    'love',
    'lugg',
    'lure',
    'maim',
    'make',
    'mask',
    'meet',
    'melt',
    'mend',
    'miss',
    'mould',
    'move',
    'nab',
    'name',
    'need',
    'oust',
    'paint',
    'paw',
    'pay',
    'peck',
    'peeve',
    'pelt',
    'please',
    'pluck',
    'poach',
    'poll',
    'praise',
    'prick',
    'print',
    'probe',
    'prod',
    'prompt',
    'punch',
    'quash',
    'quell',
    'quote',
    'raid',
    'raise',
    'raze',
    'ride',
    'roast',
    'rouse',
    'rule',
    'scald',
    'scalp',
    'scar',
    'scathe',
    'score',
    'scorn',
    'scour',
    'scuff',
    'sear',
    'see',
    'seek',
    'seize',
    'send',
    'sense',
    'serve',
    'shake',
    'shear',
    'shift',
    'shoot',
    'shun',
    'slap',
    'slay',
    'slice',
    'smack',
    'smash',
    'smell',
    'smite',
    'snare',
    'snatch',
    'sniff',
    'snub',
    'soak',
    'spare',
    'splash',
    'split',
    'spook',
    'spray',
    'squash',
    'squeeze',
    'stab',
    'stain',
    'starve',
    'steal',
    'steer',
    'sting',
    'strike',
    'stun',
    'tag',
    'tame',
    'taste',
    'taunt',
    'teach',
    'tend']



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

import pyhipku


try:
    import pypandoc
    long_description = pypandoc.convert('README.md','rst')
except (IOError, ImportError):
    with open('README.md') as f:
        long_description = f.read()


setup(
    name='pyhipku',
    version=pyhipku.__version__,
    url='http://github.com/lord63/pyhipku/',
    license='MIT',
    author='lord63',
    author_email='lord63.j@gmail.com',
    description='Encode any IP address as a haiku',
    long_description=long_description,
    packages=['pyhipku'],
    include_package_data=True,
    keywords='ip haiku',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from string import lower

from dictionary import *


def decode(haiku):
    """Decode haiku as IP address"""
    word_array = split_haiku(haiku)
    is_ipv6 = haiku_is_ipv6(word_array)
    factor_array = get_factors(word_array, is_ipv6)
    octet_array = get_octets(factor_array, is_ipv6)
    ip_string = get_ip_string(octet_array, is_ipv6)
    return ip_string


def split_haiku(haiku):
    """Split haiku, remove the period and new_line"""
    word_array = lower(haiku).replace('.', '').split()
    return word_array


def haiku_is_ipv6(word_array):
    """Weather haiku is converted from IPv6 or not, return True if it is"""
    if word_array[0] == 'the':
        is_ipv6 = False
    else:
        is_ipv6 = True
    return is_ipv6


def get_key(is_ipv6):
    """Return an array of dictionaries representing the correct word
    order for the haiku"""
    if is_ipv6:
        key = [adjectives, nouns, adjectives, nouns, verbs, adjectives,
               adjectives, adjectives, adjectives, adjectives, nouns,
               adjectives, nouns, verbs, adjectives, nouns]
    else:
        key = [animal_adjectives, animal_colors, animal_nouns, animal_verbs,
               nature_adjectives, nature_nouns, plant_nouns, plant_verbs]
    return key


def get_factors(word_array, is_ipv6):
    """Return an array of factors and remainders for each encoded word"""
    key = get_key(is_ipv6)
    # Remove the useless words, make sure there is a one-to-one match
    # between word_array and key.
    if is_ipv6:
        word_array.remove('and')
    else:
        word_array.remove('the')
        word_array.remove('in')
        word_array.remove('the')
        # Plant_nouns may have 1~3 words, join them into one.
        word_array.insert(6, ' '.join(word_array[6:-1]))
        del word_array[7:-1]
    factor_array = []
    for i in range(len(key)):
        factor_array.append(key[i].index(word_array[i]))
    return factor_array


def get_octets(factor_array, is_ipv6):
    """Return an array of octects for each pair of factor and remainder"""
    if is_ipv6:
        multiplier = 256
    else:
        multiplier = 16
    octet_array = []
    for i in range(0, len(factor_array), 2):
        result = factor_array[i]*multiplier + factor_array[i+1]
        if is_ipv6:
            origin = hex(result)[2:]
        else:
            origin = str(result)
        octet_array.append(origin)
    return octet_array


def get_ip_string(octct_array, is_ipv6):
    """Get the ip string, yeah"""
    if is_ipv6:
        separator = ':'
    else:
        separator = '.'
    ip_string = separator.join(octct_array)
    return ip_string
